# Install and create a virtual environment

It is highly recommended to work inside of a virtual environment.

- Install `virtualenv` using `pip`:
  ```
  pip install virtualenv
  ```
- Create a virtual environment:
  ```
  python -m virtualenv .venv
  ```
- Activate the virtual environment:

  ```
  .venv\Scripts\activate
  ```

  If the activation is successfull, you'll see `(.venv)` at the beginning of the terminal.
